@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2022 Rony Shapiro <ronys@pwsafe.org>.
+* Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -16,6 +16,7 @@
 #include "StringXStream.h"
 #include "UTF8Conv.h"
 #include "PWPolicy.h"
+#include "PWSLog.h"
 
 #include "os/typedefs.h"
 #include "os/debug.h"
@@ -24,7 +25,6 @@
 #include "os/env.h"
 #include "os/dir.h"
 #include "os/registry.h"
-#include "os/logit.h"
 
 #include <fstream>
 #include <algorithm>
@@ -1821,7 +1821,7 @@ stringT PWSprefs::GetXMLPreferences()
   stringT retval(_T(""));
   ostringstreamT os;
 
-  os << _S("\t<Preferences>") << endl;
+  os << _T("\t<Preferences>") << endl;
   int i;
   for (i = 0; i < NumBoolPrefs; i++) {
     if (m_boolValues[i] != m_bool_prefs[i].defVal &&
