@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2022 Rony Shapiro <ronys@pwsafe.org>.
+* Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -41,9 +41,10 @@ bool SysInfo::IsUnderPw2go()
   return !pws_os::getenv("PWS2GO", false).empty();
 }
 
-bool SysInfo::IsLinux()
+// The wxWidgets UI is used for Linux and macOS
+bool SysInfo::IsWXUI()
 {
-#ifdef __linux__
+#if defined(__linux__) || defined(__APPLE__)
   return true;
 #else
   return false;
