@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2022 Rony Shapiro <ronys@pwsafe.org>.
+* Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -36,7 +36,7 @@
 #include <sstream>
 #include <iomanip>
 
-#include <errno.h>
+#include <cerrno>
 
 using namespace std;
 
@@ -53,28 +53,54 @@ static void xormem(unsigned char *mem1, const unsigned char *mem2, int length)
 // (2) The wrong way to scrub DRAM memory
 // see http://www.cs.auckland.ac.nz/~pgut001/pubs/secure_del.html
 // and http://www.cypherpunks.to/~peter/usenix01.pdf
-
-#ifdef _WIN32
-#pragma optimize("",off)
-#endif
-void trashMemory(void *buffer, size_t length)
+namespace
 {
-  // {kjp} no point in looping around doing nothing is there?
-  if (buffer != nullptr && length > 0) {
-    std::memset(buffer, 0x55, length);
-    std::memset(buffer, 0xAA, length);
-    std::memset(buffer,    0, length);
+// Try OpenSSL's approach of forcing the call to memset through
+// a volatile function pointer.
+// https://github.com/openssl/openssl/blob/master/crypto/mem_clr.c
+
+typedef void* (*memset_t)(void*, int, size_t);
+
+volatile memset_t memset_vol = memset;
+
+void secure_memset(void* buffer, int value, size_t length)
+{
+    memset_vol(buffer, value, length);
 #ifdef __GNUC__
     // break compiler optimization of this function for gcc
     // see trick used in google's boring ssl:
     // https://boringssl.googlesource.com/boringssl/+/ad1907fe73334d6c696c8539646c21b11178f20f%5E!/#F0
     __asm__ __volatile__("" : : "r"(buffer) : "memory");
 #endif
-  }
 }
+
+void secure_zero(void* buffer, size_t length)
+{
 #ifdef _WIN32
-#pragma optimize("",on)
+    SecureZeroMemory(buffer, length);
+#else
+    memset_vol(buffer, 0, length);
+#ifdef __GNUC__
+    // break compiler optimization of this function for gcc
+    // see trick used in google's boring ssl:
+    // https://boringssl.googlesource.com/boringssl/+/ad1907fe73334d6c696c8539646c21b11178f20f%5E!/#F0
+    __asm__ __volatile__("" : : "r"(buffer) : "memory");
 #endif
+#endif
+}
+}
+
+void trashMemory(void *buffer, size_t length)
+{
+  // {kjp} no point in looping around doing nothing is there?
+  if (buffer == nullptr || length <= 0)
+      return;
+
+  secure_memset(buffer, 0x55, length);
+  secure_memset(buffer, 0xAA, length);
+  secure_zero(buffer, length);
+}
+
 void trashMemory(LPTSTR buffer, size_t length)
 {
   trashMemory(reinterpret_cast<unsigned char *>(buffer), length * sizeof(buffer[0]));
@@ -193,7 +219,6 @@ size_t _writecbc1st(FILE* fp, const unsigned char** buffer, size_t *length, unsi
 
   unsigned char* curblock = nullptr;
   ASSERT(BS <= sizeof(block1)); // if needed we can be more sophisticated here...
-
   curblock = block1;
   // Fill unused bytes of length with random data, to make
   // a dictionary attack harder
@@ -579,7 +604,7 @@ stringT PWSUtil::Base64Encode(const BYTE *strIn, size_t len)
 {
   stringT cs_Out;
   static const TCHAR base64ABC[] =
-    _S("ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/");
+    _T("ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/");
 
   for (size_t i = 0; i < len; i += 3) {
     long l = ( static_cast<long>(strIn[i]) << 16 ) |
@@ -778,54 +803,6 @@ string PWSUtil::GetXMLTime(int indent, const char *name,
   return oss.str();
 }
 
-/**
- * Get TCHAR buffer size by format string with parameters
- * @param[in] fmt - format string
- * @param[in] args - arguments for format string
- * @return buffer size including nullptr-terminating character
-*/
-unsigned int GetStringBufSize(const TCHAR *fmt, va_list args)
-{
-  TCHAR *buffer=nullptr;
-
-  unsigned int len = 0;
-
-#ifdef _WIN32
-  len = _vsctprintf(fmt, args) + 1;
-#else
-  va_list ar;
-  va_copy(ar, args);
-  // Linux doesn't do this correctly :-(
-  unsigned int guess = 16;
-  int nBytes = -1;
-  while (true) {
-    len = guess;
-    buffer = new TCHAR[len];
-    nBytes = _vstprintf_s(buffer, len, fmt, ar);
-    va_end(ar);//after using args we should reset list
-    va_copy(ar, args);
-    /*
-     * If 'nBytes' is zero due to an empty format string,
-     * it would result in an endless memory-consuming loop.
-     */
-    ASSERT(nBytes != 0);
-    if (nBytes++ > 0) {
-      len = nBytes;
-      break;
-    } else { // too small, resize & try again
-      delete[] buffer;
-      buffer = nullptr;
-      guess *= 2;
-    }
-  }
-  va_end(ar);
-#endif
-  if (buffer)
-    delete[] buffer;
-
-  return len;
-}
-
 StringX PWSUtil::DeDupString(StringX &in_string)
 {
   // Size of input string
