@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2022 Rony Shapiro <ronys@pwsafe.org>.
+* Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -275,8 +275,8 @@ bool VerifyXMLDateString(const stringT &time_str, time_t &t)
     return false;
 
   // Validate time_str
-  if (time_str.substr(4,1) != _S("-") ||
-      time_str.substr(7,1) != _S("-"))
+  if (time_str.substr(4,1) != _T("-") ||
+      time_str.substr(7,1) != _T("-"))
     return false;
 
   for (int i = 0; i < ndigits; i++) {
