@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2022 Rony Shapiro <ronys@pwsafe.org>.
+* Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -74,7 +74,7 @@ typedef uint64_t ulong64;
 typedef unsigned ulong32;
 #endif
 
-#if defined(__linux__) || defined(__CYGWIN__) || defined (macintosh) || defined(Macintosh) || defined(__APPLE__) || defined(__MACH__) || defined(__FreeBSD) || defined(__FreeBSD__)
+#if defined(__linux__) || defined(__CYGWIN__) || defined (macintosh) || defined(Macintosh) || defined(__APPLE__) || defined(__MACH__) || defined(__FreeBSD) || defined(__FreeBSD__) || defined (__OpenBSD) || defined (__OpenBSD__)
 /* Following seems needed on Linux/cygwin
    and on macs to avoid "Impossible constraint in 'asm'" errors in ROLc()
    and RORc() functions below */
@@ -385,9 +385,9 @@ static inline unsigned long ROR64c(unsigned long word, const int i)
 
 /* extract a byte portably */
 #ifdef _MSC_VER
-#define byte(x, n) (static_cast<unsigned char>((x) >> (8 * (n))))
+#define byteN(x, n) (static_cast<unsigned char>((x) >> (8 * (n))))
 #else
-#define byte(x, n) (((x) >> (8 * (n))) & 255)
+#define byteN(x, n) (((x) >> (8 * (n))) & 255)
 #endif
 #endif // !_BITOPS_H
 
