@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2022 Rony Shapiro <ronys@pwsafe.org>.
+* Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -33,6 +33,9 @@
 #include "unix/pws_time.h"
 #define _tcsdup(s) wcsdup(s)
 #endif // __FreeBSD__
+#ifdef __OpenBSD__
+#define _tcsdup(s) wcsdup(s)
+#endif // __OpenBSD__
 #include "funcwrap.h"
 #define _tcsncpy(t, s, sc) wcsncpy(t, s, sc)
 #define _tcsncpy_s wcsncpy_s
@@ -51,11 +54,11 @@
 #define _stscanf_s swscanf_s
 #ifdef __PWS_MACINTOSH__
 # include "./mac/pws_str.h"
-#define _tcsicmp pws_os::wcscasecmp
+#define _tcsicmp wcscasecmp
 #define _tcsdup pws_os::wcsdup
 #else
 #define _tcsicmp(s1, s2) wcscasecmp(s1, s2)
-# include "unix/pws_str.h"
+#include "./pws_str.h"
 #endif
 #define _ttoi(s) pws_os::wctoi(s)
 #define _tstoi(s) pws_os::wctoi(s)
