@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2003-2022 Rony Shapiro <ronys@pwsafe.org>.
+* Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
 * All rights reserved. Use of the code is allowed under the
 * Artistic License 2.0 terms, as specified in the LICENSE file
 * distributed with this code, or available from
@@ -43,7 +43,7 @@ stringT pws_os::getenv(const char *env, bool is_path)
     if (is_path) {
       // make sure path has trailing '\'
       if (retval[retval.length()-1] != charT('/'))
-        retval += _S("/");
+        retval += _T("/");
     } // is_path
   } // value != nullptr
   return retval;
