@@ -1,6 +1,6 @@
 /*
  * Created by Saurav Ghosh
- * Copyright (c) 2003-2022 Rony Shapiro <ronys@pwsafe.org>.
+ * Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
  * All rights reserved. Use of the code is allowed under the
  * Artistic License 2.0 terms, as specified in the LICENSE file
  * distributed with this code, or available from
@@ -15,7 +15,7 @@
 class PWScore;
 struct PWPolicy;
 
-int OpenCore(PWScore &core, const StringX &safe, const StringX &passphrase);
+int OpenCore(PWScore &core, const StringX &safe, const StringX &passphrase, bool openReadOnly = false);
 StringX GetNewPassphrase();
 
 int AddEntry(PWScore &core, const UserArgs &ua);
