@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2022 Rony Shapiro <ronys@pwsafe.org>.
+ * Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
  * All rights reserved. Use of the code is allowed under the
  * Artistic License 2.0 terms, as specified in the LICENSE file
  * distributed with this code, or available from
@@ -90,4 +90,16 @@ void ExternalKeyboardButton::HandleCommandEvent(wxCommandEvent& evt)
   }
 #endif
 
+#ifdef __WXOSX__
+  // If we can't open the virtual keyboard, at least open the settings app so the user can do it for us!
+  wxString command = wxString("open x-apple.systempreferences:com.apple.preference.universalaccess?Keyboard");
+
+  if ( wxExecute(command, wxEXEC_ASYNC, nullptr) > 0) {
+    wxMessageBox(_("Please, enable the Accessibility Keyboard in System Settings; the on-screen keyboard should then appear."), "", wxOK | wxICON_INFORMATION);
+  } else {
+    wxMessageBox(_("Could not launch the MacOS Settings App"),
+                  _("Could not launch external onscreen keyboard"), wxOK | wxICON_ERROR);
+  }
+#endif
+
 }
