@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2022 Rony Shapiro <ronys@pwsafe.org>.
+ * Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
  * All rights reserved. Use of the code is allowed under the
  * Artistic License 2.0 terms, as specified in the LICENSE file
  * distributed with this code, or available from
@@ -76,10 +76,10 @@ enum {
 struct SearchBarToolInfo {
   wxWindowID id;
   const wxString tooltip;
-  const char** bitmap_normal;
-  const char** bitmap_disabled;
-  const char** bitmap_classic;
-  const char** bitmap_classic_disabled;
+  const char* const* const bitmap_normal;
+  const char* const* const bitmap_disabled;
+  const char* const* const bitmap_classic;
+  const char* const* const bitmap_classic_disabled;
   wxItemKind tool_type;
 
   SearchBarToolInfo() :
@@ -90,8 +90,8 @@ struct SearchBarToolInfo {
 
   SearchBarToolInfo(
     wxWindowID id, const wxString &tooltip,
-    const char** bitmap_normal, const char** bitmap_disabled,
-    const char** bitmap_classic, const char** bitmap_classic_disabled,
+    const char* const* const bitmap_normal, const char* const* bitmap_disabled,
+    const char* const* const bitmap_classic, const char* const* bitmap_classic_disabled,
     wxItemKind tool_type
   ) :
     id(id), tooltip(tooltip),
