@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2022 Rony Shapiro <ronys@pwsafe.org>.
+ * Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
  * All rights reserved. Use of the code is allowed under the
  * Artistic License 2.0 terms, as specified in the LICENSE file
  * distributed with this code, or available from
@@ -46,9 +46,14 @@ class SystemTray : protected wxTaskBarIcon
   private:
     wxMenu* GetRecentHistory();
     wxMenu* SetupRecentEntryMenu(const CItemData* pci, size_t idx);
+    void ShowSetDatabaseIdDialog();
 
-    wxIcon iconClosed;
-    wxIcon iconUnlocked, iconLocked;
+    bool m_TrayIconWithOverlay;
+    int m_DatabaseID;
+    wxColor m_LockedDatabaseIdColor, m_UnlockedDatabaseIdColor;
+    wxIcon m_IconClosed;
+    wxIcon m_IconUnlocked, m_IconLocked;
+    wxIcon m_IconUnlockedWithID, m_IconLockedWithID;
     PasswordSafeFrame* m_frame;
     TrayStatus m_status;
 
