@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2022 Rony Shapiro <ronys@pwsafe.org>.
+ * Copyright (c) 2003-2023 Rony Shapiro <ronys@pwsafe.org>.
  * All rights reserved. Use of the code is allowed under the
  * Artistic License 2.0 terms, as specified in the LICENSE file
  * distributed with this code, or available from
@@ -276,7 +276,7 @@ void TreeCtrlBase::CreateControls()
 {
 ////@begin TreeCtrl content construction
 ////@end TreeCtrl content construction
-  const char **xpmList[] = {
+  static const char* const* const xpmList[] = {
     abase_exp_xpm,    // 0
     abase_warn_xpm,   // 1
     abase_xpm,        // 2
@@ -292,7 +292,7 @@ void TreeCtrlBase::CreateControls()
     empty_node_xpm,   // 12
   };
 #if wxVERSION_NUMBER >= 3103
-  const char **xpmDarkList[] = {
+  static const char* const* const xpmDarkList[] = {
     abase_exp_dark_xpm,    // 0
     abase_warn_dark_xpm,   // 1
     abase_dark_xpm,        // 2
